@@ -1,6 +1,8 @@
 import asyncio
 from typing import Any, Type
 
+import sentry_sdk
+
 from cats.identity import IdentityObject
 from cats.utils import require
 
@@ -37,13 +39,14 @@ class Auth:
             self.methods.append(method)
 
     async def sign_in(self, **kwargs) -> tuple[IdentityObject, Any]:
+        sentry_sdk.add_breadcrumb(message=f'Attempt to sign in', data=kwargs)
         for method in self.methods:
             try:
                 return await method.sign_in(**kwargs)
             except (KeyboardInterrupt, asyncio.CancelledError, asyncio.TimeoutError):
                 raise
-            except TypeError:
-                pass
+            except TypeError as err:
+                sentry_sdk.add_breadcrumb(message=f'Failed to signed in with {method}', error=vars(err))
         raise AuthError('Unable to authenticate')
 
     async def sign_in_silent(self, **kwargs) -> tuple[IdentityObject | None, Any | None]:
